@@ -18,7 +18,10 @@ function (X, y, ind, tind, n, k, t., nT, w, w2, coef0 = rep(0, 3),
     ## - make list of results
 
     ## now using flex optimization and sparse matrix methods
-
+    
+    ## if w2!=w has been specified, then let w=w2
+    w <- w2
+    
     ## set names for final parms vectors
     nam.beta <- dimnames(X)[[2]]
     nam.errcomp <- c("phi", "rho")
@@ -123,7 +126,7 @@ function (X, y, ind, tind, n, k, t., nT, w, w2, coef0 = rep(0, 3),
                             y, X, n, t., w, w2))$Hessian
     } else {
 
-        require(maxLik)
+        #require(maxLik)
 
         ## initial values are not allowed to be zero
         maxout<-function(x,a) ifelse(x>a, x, a)
